@@ -35,6 +35,10 @@
 //! support. This feature depends on unstable feature and requires the use of the nightly channel.
 //!
 //! - `homogeneous`. This opt-in feature enables the *experimental* homogeneous multi-core support.
+//!
+//! - `cortex-m-7`. This opt-in feature changes the `cortex-m` version from the default 0.6 to the newer 0.7.
+//! This is to use the `InterruptNumber` trait instead of the `Nr` trait for interrupt numbers.
+//! Enabling this feature **requires disabling the default features**.
 
 #![deny(missing_docs)]
 #![deny(rust_2018_compatibility)]
@@ -53,8 +57,6 @@ extern crate cortex_m_7 as cortex_m;
 use cortex_m::interrupt::InterruptNumber;
 
 use cortex_m::peripheral::{CBP, CPUID, DCB, DWT, FPB, FPU, ITM, MPU, NVIC, SCB, TPIU};
-#[cfg(all(not(feature = "heterogeneous"), not(feature = "homogeneous")))]
-use cortex_m_rt as _; // vector table
 pub use cortex_m_rtic_macros::app;
 pub use rtic_core::{Exclusive, Mutex};
 
